@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 2004 George Lebl
+ * Copyright (C) 2004-2005 George Lebl
  *
  * Author: George Lebl
  *
@@ -25,16 +25,23 @@
 typedef struct {
 	gboolean error_box;
 	gboolean info_box;
+	gboolean blinking_cursor;
 	int scrollback;
 	char *font;
+	gboolean black_on_white;
 } GeniusSetup;
 
 extern GeniusSetup genius_setup;
 extern GtkWidget *genius_window;
-extern gboolean interrupted;
 extern GHashTable *uncompiled;
 extern calcstate_t calcstate;
 
 void genius_interrupt_calc (void);
 
+void genius_setup_window_cursor (GtkWidget *win, GdkCursorType type);
+void genius_unsetup_window_cursor (GtkWidget *win);
+
+gboolean genius_ask_question (GtkWidget *parent, const char *question);
+void genius_display_error (GtkWidget *parent, const char *err);
+
 #endif /* GNOME_GENIUS_H_ */
